@@ -24,7 +24,7 @@
 
 #include <glib.h>
 
-#include <libmissioncontrol/mission-control.h>
+#include <telepathy-glib/enums.h>
 
 G_BEGIN_DECLS
 
@@ -49,24 +49,21 @@ struct _EmpathyIdleClass {
 
 GType        empathy_idle_get_type            (void) G_GNUC_CONST;
 EmpathyIdle *empathy_idle_dup_singleton       (void);
-McPresence   empathy_idle_get_state           (EmpathyIdle *idle);
+TpConnectionPresenceType   empathy_idle_get_state           (EmpathyIdle *idle);
 void         empathy_idle_set_state           (EmpathyIdle *idle,
-					       McPresence   state);
+					       TpConnectionPresenceType   state);
 const gchar *empathy_idle_get_status          (EmpathyIdle *idle);
 void         empathy_idle_set_status          (EmpathyIdle *idle,
 					       const gchar *status);
-McPresence   empathy_idle_get_flash_state     (EmpathyIdle *idle);
+TpConnectionPresenceType   empathy_idle_get_flash_state     (EmpathyIdle *idle);
 void         empathy_idle_set_flash_state     (EmpathyIdle *idle,
-					       McPresence   state);
+					       TpConnectionPresenceType   state);
 void         empathy_idle_set_presence        (EmpathyIdle *idle,
-					       McPresence   state,
+					       TpConnectionPresenceType   state,
 					       const gchar *status);
 gboolean     empathy_idle_get_auto_away       (EmpathyIdle *idle);
 void         empathy_idle_set_auto_away       (EmpathyIdle *idle,
 					       gboolean     auto_away);
-gboolean     empathy_idle_get_use_nm          (EmpathyIdle *idle);
-void         empathy_idle_set_use_nm          (EmpathyIdle *idle,
-					       gboolean     use_nm);
 
 G_END_DECLS
 
