@@ -216,9 +216,6 @@ get_default_display_name (EmpathyAccountSettings *settings)
   login_id = empathy_account_settings_get_string (settings, "account");
   protocol = empathy_account_settings_get_protocol (settings);
 
-  if ((p = empathy_protocol_name_to_display_name (protocol)) != NULL)
-    protocol = p;
-
   if (login_id != NULL)
     {
       if (!tp_strdiff (protocol, "irc"))
@@ -238,8 +235,14 @@ get_default_display_name (EmpathyAccountSettings *settings)
         {
           default_display_name = g_strdup (login_id);
         }
+
+      return default_display_name;
     }
-  else if (protocol != NULL)
+
+  if ((p = empathy_protocol_name_to_display_name (protocol)) != NULL)
+    protocol = p;
+
+  if (protocol != NULL)
     {
       /* To translators: The parameter is the protocol name. The resulting
        * string will be something like: "Jabber Account" */
@@ -1757,6 +1760,9 @@ do_constructor (GType type,
 
       dialog_singleton = EMPATHY_ACCOUNTS_DIALOG (retval);
       g_object_add_weak_pointer (retval, (gpointer) &dialog_singleton);
+      /* We add an extra reference that we'll release when the dialog is
+       * destroyed (accounts_dialog_destroy_cb) */
+      g_object_ref (retval);
     }
 
   return retval;
@@ -1895,6 +1901,9 @@ empathy_accounts_dialog_show (GtkWindow *parent,
     }
 
   gtk_window_present (GTK_WINDOW (priv->window));
+  /* EmpathyAccountsDialog kepts a ref on itself until the dialog is
+   * destroyed so we can release the ref returned by the constructor now. */
+  g_object_unref (dialog);
 
   return priv->window;
 }
