@@ -620,8 +620,9 @@ empathy_call_window_setup_self_frame (GstBus *bus, EmpathyCallWindow *self)
   gst_object_ref (priv->audio_input);
   gst_object_sink (priv->audio_input);
 
-  g_signal_connect (priv->audio_input, "peak-level-changed",
-    G_CALLBACK (empathy_call_window_audio_input_level_changed_cb), self);
+  empathy_signal_connect_weak (priv->audio_input, "peak-level-changed",
+    G_CALLBACK (empathy_call_window_audio_input_level_changed_cb),
+    G_OBJECT (self));
 }
 
 static void
@@ -887,8 +888,18 @@ static void
 contact_avatar_changed_cb (EmpathyContact *contact,
     GParamSpec *pspec, GtkWidget *avatar_widget)
 {
-  init_contact_avatar_with_size (contact, avatar_widget,
-      avatar_widget->allocation.height);
+  int size;
+
+  size = avatar_widget->allocation.height;
+
+  if (size == 0)
+    {
+      /* the widget is not allocated yet, set a default size */
+      size = MIN (REMOTE_CONTACT_AVATAR_DEFAULT_HEIGHT,
+          REMOTE_CONTACT_AVATAR_DEFAULT_WIDTH);
+    }
+
+  init_contact_avatar_with_size (contact, avatar_widget, size);
 }
 
 static void
@@ -932,7 +943,7 @@ empathy_call_window_setup_avatars (EmpathyCallWindow *self,
       factory = empathy_tp_contact_factory_dup_singleton (connection);
       empathy_tp_contact_factory_get_from_handle (factory,
           tp_connection_get_self_handle (connection),
-          empathy_call_window_got_self_contact_cb, self, NULL, NULL);
+          empathy_call_window_got_self_contact_cb, self, NULL, G_OBJECT (self));
 
       g_object_unref (factory);
     }
@@ -1077,10 +1088,9 @@ empathy_call_window_dispose (GObject *object)
     {
       g_signal_handlers_disconnect_by_func (call,
         empathy_call_window_video_stream_changed_cb, object);
+      g_object_unref (call);
     }
 
-  g_object_unref (call);
-
   if (priv->handler != NULL)
     g_object_unref (priv->handler);
   priv->handler = NULL;
